Package: radiant.design
Type: Package
Title: Design Menu for Radiant: Business Analytics using R and Shiny
Version: 1.6.6
Date: 2024-5-14
Authors@R: person("Vincent", "Nijs", , "radiant@rady.ucsd.edu", c("aut", "cre"))
Description: The Radiant Design menu includes interfaces for design of
    experiments, sampling, and sample size calculation. The application extends
    the functionality in 'radiant.data'.
Depends: R (>= 4.3.0), radiant.data (>= 1.6.6),
Imports: dplyr (>= 1.0.7), magrittr (>= 1.5), shiny (>= 1.8.1),
        AlgDesign (>= 1.1.7.3), import (>= 1.1.0), pwr (>= 1.1.2),
        randomizr (>= 0.20.0), mvtnorm (>= 1.2.0), polycor
Suggests: testthat (>= 2.0.0), pkgdown (>= 1.1.0)
URL: https://github.com/radiant-rstats/radiant.design/,
        https://radiant-rstats.github.io/radiant.design/,
        https://radiant-rstats.github.io/docs/
BugReports: https://github.com/radiant-rstats/radiant.design/issues/
License: AGPL-3 | file LICENSE
LazyData: true
Encoding: UTF-8
RoxygenNote: 7.3.1
NeedsCompilation: no
Packaged: 2024-05-15 02:25:33 UTC; vnijs
Author: Vincent Nijs [aut, cre]
Maintainer: Vincent Nijs <radiant@rady.ucsd.edu>
Repository: CRAN
Date/Publication: 2024-05-15 04:30:02 UTC
Built: R 4.6.0; ; 2026-04-25 14:09:32 UTC; unix
