# Generated by roxygen2: do not edit by hand

S3method(plot,sample_size_comp)
S3method(summary,doe)
S3method(summary,randomizer)
S3method(summary,sample_size)
S3method(summary,sample_size_comp)
S3method(summary,sampling)
export(doe)
export(estimable)
export(radiant.design)
export(radiant.design_viewer)
export(radiant.design_window)
export(randomizer)
export(sample_size)
export(sample_size_comp)
export(sampling)
import(radiant.data)
import(shiny)
importFrom(AlgDesign,optFederov)
importFrom(dplyr,"%>%")
importFrom(dplyr,arrange)
importFrom(dplyr,arrange_at)
importFrom(dplyr,bind_cols)
importFrom(dplyr,desc)
importFrom(dplyr,distinct)
importFrom(dplyr,right_join)
importFrom(dplyr,select_at)
importFrom(import,from)
importFrom(magrittr,"%<>%")
importFrom(magrittr,set_colnames)
importFrom(mvtnorm,pmvnorm)
importFrom(polycor,hetcor)
importFrom(pwr,ES.h)
importFrom(pwr,plot.power.htest)
importFrom(pwr,pwr.2p.test)
importFrom(pwr,pwr.2p2n.test)
importFrom(pwr,pwr.t.test)
importFrom(pwr,pwr.t2n.test)
importFrom(radiant.data,launch)
importFrom(randomizr,block_ra)
importFrom(randomizr,complete_ra)
importFrom(stats,addmargins)
importFrom(stats,as.formula)
importFrom(stats,coef)
importFrom(stats,cor)
importFrom(stats,lm)
importFrom(stats,na.omit)
importFrom(stats,power.prop.test)
importFrom(stats,power.t.test)
importFrom(stats,qnorm)
importFrom(stats,runif)
